(api)=

# API Reference

:::{seealso}
For granular control see {ref}`libvcs <libvcs:index>`'s {ref}`Commands <libvcs:cmd>` and {ref}`Projects <libvcs:projects>`.
:::

## Internals

:::{warning}
Be careful with these! Internal APIs are **not** covered by version policies. They can break or be removed between minor versions!

If you need an internal API stabilized please [file an issue](https://github.com/vcs-python/vcspull/issues).
:::

## Exceptions

```{eval-rst}
.. autoexception:: vcspull.exc.VCSPullException
```

```{eval-rst}
.. autoexception:: vcspull.exc.MultipleConfigWarning
```
